@@ -16,7 +16,7 @@ also be used as template for Python modules.
 Note: This skeleton file can be safely removed if not needed!
 
 ```bash
-$ bot -b 'pattern,parul' -vv -p --num_top_replies=1
+$ bot -b 'pattern,eliza' -vv -p --num_top_replies=1
 YOU: Hi
 bot: Hello!
 YOU: Looking good!
@@ -59,7 +59,7 @@ BOT = None
 class CLIBot:
     """ Conversation manager interacting with user on the command line
 
-    >>> bot = CLIBot(skill_module_names='parul,pattern'.split(','), num_top_replies=1)
+    >>> bot = CLIBot(skill_module_names='eliza,pattern'.split(','), num_top_replies=1)
     >>> bot.reply('Hi')[1]
     'Hello!'
     >>> bot.reply(statement=None, context=None)
@@ -222,7 +222,6 @@ def run_skill():
             skill_module_names=constants.args.bots,
             num_top_replies=constants.args.num_top_replies,
             semantic=constants.args.semantic,
-            sentiment=constants.args.sentiment,
             spell=constants.args.spell)
     if constants.args.persist:
         print('Type "quit" or "exit" to end the conversation...')
